@@ -56,7 +56,21 @@ class DataHashicupsCoffees(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DataHashicupsCoffees.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id_: builtins.str,
+                *,
+                id: typing.Optional[builtins.str] = None,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = DataHashicupsCoffeesConfig(
@@ -103,7 +117,9 @@ class DataHashicupsCoffees(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataHashicupsCoffees, "id").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -167,7 +183,13 @@ class DataHashicupsCoffeesCoffeesIngredientsList(
         :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DataHashicupsCoffeesCoffeesIngredientsList.__init__)
+            def stub(
+                terraform_resource: cdktf.IInterpolatingParent,
+                terraform_attribute: builtins.str,
+                wraps_set: builtins.bool,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
             check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
@@ -182,7 +204,9 @@ class DataHashicupsCoffeesCoffeesIngredientsList(
         :param index: the index of the item to return.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DataHashicupsCoffeesCoffeesIngredientsList.get)
+            def stub(index: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument index", value=index, expected_type=type_hints["index"])
         return typing.cast("DataHashicupsCoffeesCoffeesIngredientsOutputReference", jsii.invoke(self, "get", [index]))
 
@@ -195,7 +219,9 @@ class DataHashicupsCoffeesCoffeesIngredientsList(
     @_terraform_attribute.setter
     def _terraform_attribute(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataHashicupsCoffeesCoffeesIngredientsList, "_terraform_attribute").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "terraformAttribute", value)
 
@@ -208,7 +234,9 @@ class DataHashicupsCoffeesCoffeesIngredientsList(
     @_terraform_resource.setter
     def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataHashicupsCoffeesCoffeesIngredientsList, "_terraform_resource").fset)
+            def stub(value: cdktf.IInterpolatingParent) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "terraformResource", value)
 
@@ -221,7 +249,9 @@ class DataHashicupsCoffeesCoffeesIngredientsList(
     @_wraps_set.setter
     def _wraps_set(self, value: builtins.bool) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataHashicupsCoffeesCoffeesIngredientsList, "_wraps_set").fset)
+            def stub(value: builtins.bool) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "wrapsSet", value)
 
@@ -245,7 +275,14 @@ class DataHashicupsCoffeesCoffeesIngredientsOutputReference(
         :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DataHashicupsCoffeesCoffeesIngredientsOutputReference.__init__)
+            def stub(
+                terraform_resource: cdktf.IInterpolatingParent,
+                terraform_attribute: builtins.str,
+                complex_object_index: jsii.Number,
+                complex_object_is_from_set: builtins.bool,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
             check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
@@ -268,7 +305,11 @@ class DataHashicupsCoffeesCoffeesIngredientsOutputReference(
         value: typing.Optional[DataHashicupsCoffeesCoffeesIngredients],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataHashicupsCoffeesCoffeesIngredientsOutputReference, "internal_value").fset)
+            def stub(
+                value: typing.Optional[DataHashicupsCoffeesCoffeesIngredients],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -290,7 +331,13 @@ class DataHashicupsCoffeesCoffeesList(
         :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DataHashicupsCoffeesCoffeesList.__init__)
+            def stub(
+                terraform_resource: cdktf.IInterpolatingParent,
+                terraform_attribute: builtins.str,
+                wraps_set: builtins.bool,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
             check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
@@ -302,7 +349,9 @@ class DataHashicupsCoffeesCoffeesList(
         :param index: the index of the item to return.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DataHashicupsCoffeesCoffeesList.get)
+            def stub(index: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument index", value=index, expected_type=type_hints["index"])
         return typing.cast("DataHashicupsCoffeesCoffeesOutputReference", jsii.invoke(self, "get", [index]))
 
@@ -315,7 +364,9 @@ class DataHashicupsCoffeesCoffeesList(
     @_terraform_attribute.setter
     def _terraform_attribute(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataHashicupsCoffeesCoffeesList, "_terraform_attribute").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "terraformAttribute", value)
 
@@ -328,7 +379,9 @@ class DataHashicupsCoffeesCoffeesList(
     @_terraform_resource.setter
     def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataHashicupsCoffeesCoffeesList, "_terraform_resource").fset)
+            def stub(value: cdktf.IInterpolatingParent) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "terraformResource", value)
 
@@ -341,7 +394,9 @@ class DataHashicupsCoffeesCoffeesList(
     @_wraps_set.setter
     def _wraps_set(self, value: builtins.bool) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataHashicupsCoffeesCoffeesList, "_wraps_set").fset)
+            def stub(value: builtins.bool) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "wrapsSet", value)
 
@@ -365,7 +420,14 @@ class DataHashicupsCoffeesCoffeesOutputReference(
         :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DataHashicupsCoffeesCoffeesOutputReference.__init__)
+            def stub(
+                terraform_resource: cdktf.IInterpolatingParent,
+                terraform_attribute: builtins.str,
+                complex_object_index: jsii.Number,
+                complex_object_is_from_set: builtins.bool,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
             check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
@@ -418,7 +480,9 @@ class DataHashicupsCoffeesCoffeesOutputReference(
         value: typing.Optional[DataHashicupsCoffeesCoffees],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataHashicupsCoffeesCoffeesOutputReference, "internal_value").fset)
+            def stub(value: typing.Optional[DataHashicupsCoffeesCoffees]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -463,7 +527,19 @@ class DataHashicupsCoffeesConfig(cdktf.TerraformMetaArguments):
         if isinstance(lifecycle, dict):
             lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
         if __debug__:
-            type_hints = typing.get_type_hints(DataHashicupsCoffeesConfig.__init__)
+            def stub(
+                *,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+                id: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
